==> javax.xml-1.0.2.jar: javax/xml/crypto/OctetStreamData.clj <==
(ns javax.xml.crypto.OctetStreamData
  "A representation of a Data type containing an octet stream."
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.xml.crypto OctetStreamData]))

(defn ->octet-stream-data
  "Constructor.

  Creates a new OctetStreamData.

  octet-stream - the input stream containing the octets - `java.io.InputStream`
  uri - the URI String identifying the data object (may be null) - `java.lang.String`
  mime-type - the MIME type associated with the data object (may be null) - `java.lang.String`

  throws: java.lang.NullPointerException - if octetStream is null"
  ([^java.io.InputStream octet-stream ^java.lang.String uri ^java.lang.String mime-type]
    (new OctetStreamData octet-stream uri mime-type))
  ([^java.io.InputStream octet-stream]
    (new OctetStreamData octet-stream)))

(defn get-octet-stream
  "Returns the input stream of this OctetStreamData.

  returns: the input stream of this OctetStreamData. - `java.io.InputStream`"
  ([^javax.xml.crypto.OctetStreamData this]
    (-> this (.getOctetStream))))

(defn get-uri
  "Returns the URI String identifying the data object represented by this
   OctetStreamData.

  returns: the URI String or null if not applicable - `java.lang.String`"
  ([^javax.xml.crypto.OctetStreamData this]
    (-> this (.getURI))))

(defn get-mime-type
  "Returns the MIME type associated with the data object represented by this
   OctetStreamData.

  returns: the MIME type or null if not applicable - `java.lang.String`"
  ([^javax.xml.crypto.OctetStreamData this]
    (-> this (.getMimeType))))

==> javax.xml-1.0.3.jar: javax/xml/crypto/OctetStreamData.clj <==
(ns javax.xml.crypto.OctetStreamData
  "A representation of a Data type containing an octet stream."
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.xml.crypto OctetStreamData]))

(defn ->octet-stream-data
  "Constructor.

  Creates a new OctetStreamData.

  octet-stream - the input stream containing the octets - `java.io.InputStream`
  uri - the URI String identifying the data object (may be null) - `java.lang.String`
  mime-type - the MIME type associated with the data object (may be null) - `java.lang.String`

  throws: java.lang.NullPointerException - if octetStream is null"
  ([^java.io.InputStream octet-stream ^java.lang.String uri ^java.lang.String mime-type]
    (new OctetStreamData octet-stream uri mime-type))
  ([^java.io.InputStream octet-stream]
    (new OctetStreamData octet-stream)))

(defn get-octet-stream
  "Returns the input stream of this OctetStreamData.

  returns: the input stream of this OctetStreamData. - `java.io.InputStream`"
  (^java.io.InputStream [^javax.xml.crypto.OctetStreamData this]
    (-> this (.getOctetStream))))

(defn get-uri
  "Returns the URI String identifying the data object represented by this
   OctetStreamData.

  returns: the URI String or null if not applicable - `java.lang.String`"
  (^java.lang.String [^javax.xml.crypto.OctetStreamData this]
    (-> this (.getURI))))

(defn get-mime-type
  "Returns the MIME type associated with the data object represented by this
   OctetStreamData.

  returns: the MIME type or null if not applicable - `java.lang.String`"
  (^java.lang.String [^javax.xml.crypto.OctetStreamData this]
    (-> this (.getMimeType))))
